==> horizon_13.0.0.orig.tar.gz: horizon-13.0.0/horizon/test/unit/hacking/test_checks.py <==
#    Copyright 2015 Intel, Inc.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import textwrap

import mock
import pep8

from horizon.hacking import checks
from horizon.test import helpers


class HackingTestCase(helpers.TestCase):
    """This class tests the hacking checks in horizon.hacking.checks.

    Each check passes passing strings to the check methods like the
    pep8/flake8 parser would. The parser loops over each line in the
    file and then passes the parameters to the check method.
    The parameter names in the check method dictate what type of
    object is passed to the check method. The parameter types are:

    logical_line
        A processed line with the following modifications:

        - Multi-line statements converted to a single line.
        - Stripped left and right.
        - Contents of strings replaced with "xxx" of same length.
        - Comments removed.

    physical_line
        Raw line of text from the input file.

    lines
        a list of the raw lines from the input file

    tokens
        the tokens that contribute to this logical line

    line_number
        line number in the input file

    total_lines
        number of lines in the input file

    blank_lines
        blank lines before this one

    indent_char
        indentation character in this file (" " or "\t")

    indent_level
        indentation (with tabs expanded to multiples of 8)

    previous_indent_level
        indentation on previous line

    previous_logical
        previous logical line

    filename
        Path of the file being run through pep8

    When running a test on a check method the return will be False/None if
    there is no violation in the sample input. If there is an error a tuple is
    returned with a position in the line, and a message. So to check the result
    just assertTrue if the check is expected to fail and assertFalse if it
    should pass.
    """
    # We are patching pep8 so that only the check under test is actually
    # installed.

    @mock.patch('pep8._checks',
                {'physical_line': {}, 'logical_line': {}, 'tree': {}})
    def _run_check(self, code, checker, filename=None):
        pep8.register_check(checker)

        lines = textwrap.dedent(code).strip().splitlines(True)

        checker = pep8.Checker(filename=filename, lines=lines)
        checker.check_all()
        checker.report._deferred_print.sort()
        return checker.report._deferred_print

    def _assert_has_errors(self, code, checker, expected_errors=None,
                           filename=None):
        actual_errors = [e[:3] for e in
                         self._run_check(code, checker, filename)]
        self.assertEqual(expected_errors or [], actual_errors)

    def _assert_has_no_errors(self, code, checker, filename=None):
        self._assert_has_errors(code, checker, filename=filename)

    def test_no_mutable_default_args(self):
        self.assertEqual(1, len(list(checks.no_mutable_default_args(
            "def get_info_from_bdm(virt_type, bdm, mapping=[])"))))

        self.assertEqual(0, len(list(checks.no_mutable_default_args(
            "defined = []"))))

        self.assertEqual(0, len(list(checks.no_mutable_default_args(
            "defined, undefined = [], {}"))))

==> horizon_16.0.0.orig.tar.gz: horizon-16.0.0/horizon/test/unit/hacking/test_checks.py <==
#    Copyright 2015 Intel, Inc.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import textwrap

import mock
import pycodestyle

from horizon.hacking import checks
from horizon.test import helpers


class HackingTestCase(helpers.TestCase):
    """This class tests the hacking checks in horizon.hacking.checks.

    Each check passes passing strings to the check methods like the
    pep8/flake8 parser would. The parser loops over each line in the
    file and then passes the parameters to the check method.
    The parameter names in the check method dictate what type of
    object is passed to the check method. The parameter types are:

    logical_line
        A processed line with the following modifications:

        - Multi-line statements converted to a single line.
        - Stripped left and right.
        - Contents of strings replaced with "xxx" of same length.
        - Comments removed.

    physical_line
        Raw line of text from the input file.

    lines
        a list of the raw lines from the input file

    tokens
        the tokens that contribute to this logical line

    line_number
        line number in the input file

    total_lines
        number of lines in the input file

    blank_lines
        blank lines before this one

    indent_char
        indentation character in this file (" " or "\t")

    indent_level
        indentation (with tabs expanded to multiples of 8)

    previous_indent_level
        indentation on previous line

    previous_logical
        previous logical line

    filename
        Path of the file being run through pep8

    When running a test on a check method the return will be False/None if
    there is no violation in the sample input. If there is an error a tuple is
    returned with a position in the line, and a message. So to check the result
    just assertTrue if the check is expected to fail and assertFalse if it
    should pass.
    """
    # We are patching pep8 so that only the check under test is actually
    # installed.

    @mock.patch('pycodestyle._checks',
                {'physical_line': {}, 'logical_line': {}, 'tree': {}})
    def _run_check(self, code, checker, filename=None):
        pycodestyle.register_check(checker)

        lines = textwrap.dedent(code).strip().splitlines(True)

        checker = pycodestyle.Checker(filename=filename, lines=lines)
        checker.check_all()
        checker.report._deferred_print.sort()
        return checker.report._deferred_print

    def _assert_has_errors(self, code, checker, expected_errors=None,
                           filename=None):
        actual_errors = [e[:3] for e in
                         self._run_check(code, checker, filename)]
        self.assertEqual(expected_errors or [], actual_errors)

    def _assert_has_no_errors(self, code, checker, filename=None):
        self._assert_has_errors(code, checker, filename=filename)

    def test_no_mutable_default_args(self):
        self.assertEqual(1, len(list(checks.no_mutable_default_args(
            "def get_info_from_bdm(virt_type, bdm, mapping=[])"))))

        self.assertEqual(0, len(list(checks.no_mutable_default_args(
            "defined = []"))))

        self.assertEqual(0, len(list(checks.no_mutable_default_args(
            "defined, undefined = [], {}"))))
